.. rpaudio documentation master file, created by
   sphinx-quickstart on Sat Aug 10 04:01:24 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

rpaudio Documentation
=====================

Welcome to the rpaudio documentation!

Contents:
---------

.. toctree::
   :maxdepth: 2

   quickstart
   examples/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
